==> subtitlecomposer_0.6.4.orig.tar.gz: subtitlecomposer-0.6.4/src/videoplayerplugins/mpv/mpvconfigwidget.cpp <==
/**
 * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
 * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "mpvconfigwidget.h"

using namespace SubtitleComposer;

MPVConfigWidget::MPVConfigWidget(QWidget *parent)
	: QWidget(parent)
{
	setupUi(this);

	kcfg_mpvVideoOutput->addItems(QString("vdpau vaapi xv wayland opengl opengl-hq opengl-old x11 null").split(' '));
	kcfg_mpvVideoOutput->setProperty("kcfg_property", QByteArray("currentText"));

	kcfg_mpvHwDecode->addItems(QString("auto vdpau vaapi vaapi-copy").split(' '));
	kcfg_mpvHwDecode->setProperty("kcfg_property", QByteArray("currentText"));

	kcfg_mpvAudioOutput->addItems(QString("pulse alsa oss portaudio jack null").split(' '));
	kcfg_mpvAudioOutput->setProperty("kcfg_property", QByteArray("currentText"));
}

MPVConfigWidget::~MPVConfigWidget()
{

}

==> subtitlecomposer_0.6.6.orig.tar.gz: subtitlecomposer-0.6.6/src/videoplayerplugins/mpv/mpvconfigwidget.cpp <==
/*
 * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
 * Copyright (C) 2010-2017 Mladen Milinkovic <max@smoothware.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "mpvconfigwidget.h"

using namespace SubtitleComposer;

MPVConfigWidget::MPVConfigWidget(QWidget *parent)
	: QWidget(parent)
{
	setupUi(this);

	kcfg_mpvVideoOutput->addItems(QString("vdpau vaapi opengl opengl-hq sdl xv wayland x11 null").split(' '));
	kcfg_mpvVideoOutput->setProperty("kcfg_property", QByteArray("currentText"));

	kcfg_mpvHwDecode->addItems(QString("auto vdpau vaapi vaapi-copy").split(' '));
	kcfg_mpvHwDecode->setProperty("kcfg_property", QByteArray("currentText"));

	kcfg_mpvAudioOutput->addItems(QString("pulse alsa oss portaudio jack null").split(' '));
	kcfg_mpvAudioOutput->setProperty("kcfg_property", QByteArray("currentText"));
}

MPVConfigWidget::~MPVConfigWidget()
{

}
